<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet SYSTEM "Performance Test Report.dtd">
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:gfn="http://www.greenhatsoftware.com/Functions.xsl"
	exclude-result-prefixes="gfn">

	<xsl:import href="Utils/Misc.xsl" />
	<xsl:import href="Detailed%20Report.xsl" />

	<xsl:output method="html" encoding="UTF-8" indent="yes" />

	<!-- externalisations -->
	<xsl:variable name="perfTestReport.resourceNameAndReportTitle">
		<xsl:text>&perfTestReport.resourceNameAndReportTitle;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.testName">
		<xsl:text>&perfTestReport.testName;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.environment">
		<xsl:text>&perfTestReport.environment;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.startTime">
		<xsl:text>&perfTestReport.startTime;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.endTime">
		<xsl:text>&perfTestReport.endTime;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.runTime">
		<xsl:text>&perfTestReport.runTime;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.running">
		<xsl:text>&perfTestReport.running;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.summary">
		<xsl:text>&perfTestReport.summary;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.iterations">
		<xsl:text>&perfTestReport.iterations;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.iterationsAvgTime">
		<xsl:text>&perfTestReport.iterationsAvgTime;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.iterationsMaxTime">
		<xsl:text>&perfTestReport.iterationsMaxTime;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.transactions">
		<xsl:text>&perfTestReport.transactions;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.transAvgTime">
		<xsl:text>&perfTestReport.transAvgTime;</xsl:text>
	</xsl:variable>
	<xsl:variable name="perfTestReport.transMaxTime">
		<xsl:text>&perfTestReport.transMaxTime;</xsl:text>
	</xsl:variable>

	<xsl:param name="contextName" />
	<xsl:param name="title"
		select="gfn:formatString($perfTestReport.resourceNameAndReportTitle,tokenize($contextName,'/')[last()])" />

	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:value-of select="$title" />
				</title>
				<link rel="stylesheet" type="text/css" href="resourcestyle.css" />
			</head>
			<body>
				<a name="top" />
				<xsl:call-template name="perfhead">
				</xsl:call-template>
				<xsl:call-template name="perftable">
				</xsl:call-template>
			</body>
		</html>
	</xsl:template>

	<xsl:template name="perfhead">
		<div style="margin: 0px 0px 0px 0px;">
			<img src="logo.jpg" alt="Logo" style="float: left;"
				border="0" />
			<h1>
				<xsl:value-of select="$title" />
			</h1>
			<table class="faux">
				<tr>
					<th>
						<xsl:value-of select="$perfTestReport.testName" />
					</th>
					<td>
						<xsl:value-of select="$contextName" />
					</td>
				</tr>
				<tr>
					<th>
						<xsl:value-of select="$perfTestReport.environment" />
					</th>
					<td>
						<xsl:value-of select="PerfTest/@environment" />
					</td>
				</tr>
				<tr>
					<th>
						<xsl:value-of select="$perfTestReport.startTime" />
					</th>
					<td>
						<xsl:value-of select="PerfTest/@startTime" />
					</td>
				</tr>
				<tr>
					<th>
						<xsl:value-of select="$perfTestReport.endTime" />
					</th>
					<td>
						<xsl:value-of select="PerfTest/@endTime" />
					</td>
				</tr>
				<tr>
					<xsl:call-template name="writeNameValuePair">
						<xsl:with-param name="name" select="$perfTestReport.runTime" />
						<xsl:with-param name="value">
							<xsl:choose>
								<xsl:when test="PerfTest/@duration">
									<xsl:value-of select="PerfTest/@duration" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$perfTestReport.running" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</tr>
			</table>
		</div>
	</xsl:template>

	<xsl:template name="perftable">
		<h2>
			<xsl:value-of select="$perfTestReport.summary" />
		</h2>
		<table>
			<tr>
				<th>
					<xsl:value-of select="$perfTestReport.iterations" />
				</th>
				<th>
					<xsl:value-of select="$perfTestReport.iterationsAvgTime" />
				</th>
				<th>
					<xsl:value-of select="$perfTestReport.iterationsMaxTime" />
				</th>
				<th>
					<xsl:value-of select="$perfTestReport.transactions" />
				</th>
				<th>
					<xsl:value-of select="$perfTestReport.transAvgTime" />
				</th>
				<th>
					<xsl:value-of select="$perfTestReport.transMaxTime" />
				</th>
			</tr>
			<tr>
				<td>
					<xsl:value-of select="PerfTest/@iterations" />
				</td>
				<td>
					<xsl:value-of select="PerfTest/@avgIterDur" />
				</td>
				<td>
					<xsl:value-of select="PerfTest/@maxIterDur" />
				</td>
				<td>
					<xsl:value-of select="PerfTest/@transactions" />
				</td>
				<td>
					<xsl:value-of select="PerfTest/@avgTransDur" />
				</td>
				<td>
					<xsl:value-of select="PerfTest/@maxTransDur" />
				</td>
			</tr>
		</table>
	</xsl:template>
</xsl:stylesheet>
