--
-- Migrate database from schema version 1.9.24.e to 1.9.24.f
--
DROP PROCEDURE IF EXISTS update_gh_schema;

DELIMITER //
CREATE PROCEDURE update_gh_schema()
BEGIN
  DECLARE current_version varchar(100);
  SET @required_version = '1.9.24.e';

  SELECT value INTO current_version FROM db_details WHERE 
         property='schema.version.number' AND 
         ctime = (
            SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number'
         );
  IF @required_version != current_version THEN
     SET @version_error = CONCAT( 'Incorrect schema version: ', current_version,
                                  ' expected: ', @required_version );
     SELECT @version_error;
  ELSE

--
-- The update script
--

CREATE VIEW SCENARIO_EXECUTIONS_SUBQUERY_ONE AS
SELECT sue.execution_id, app.id, app.uniqueid, app.display, app.project_id, sue.expiration
	FROM suite_execution sue, appmodelitem app
	WHERE sue.appmodelitem_id = app.id
;
    
CREATE VIEW SCENARIO_EXECUTIONS_SUBQUERY_TWO AS
SELECT el.execution_id, p.username, el.time
	FROM execution_lock el, person p
	WHERE el.person_id = p.id
;

CREATE VIEW SCENARIO_EXECUTIONS
(EXECUTION_ID, 
LABEL, 
LOCKBY, 
LOCKDATE,
NOTES_PK,
PROJECT_PK,
SUITE_PK,
SUITE_ID,
SUITE_NAME,
SCENARIO_NAME,
SCENARIO_ID,
START_TIME,
END_TIME,
STATUS,
EXPIRES,
ROOT_EXEC_ID) AS
SELECT sce.execution_id, l.label, u.username, u.time, n.execution_id, t.project_id, t.id, t.uniqueid, t.display, s.display, s.uniqueid, e.start_time, e.end_time, (SELECT display FROM status WHERE id = e.status_id), t.expiration, e.root_id
FROM scenario s, scenario_execution sce, execution e
LEFT OUTER JOIN execution_label l ON e.id = l.execution_id
LEFT OUTER JOIN SCENARIO_EXECUTIONS_SUBQUERY_ONE t ON e.id = t.execution_id
LEFT OUTER JOIN SCENARIO_EXECUTIONS_SUBQUERY_TWO u ON e.id = u.execution_id
LEFT OUTER JOIN execution_note n ON e.id = n.execution_id
WHERE e.id = sce.execution_id AND sce.scenario_id = s.id
;

INSERT INTO db_details VALUES
   ( now(), 'schema.version.number','1.9.24.f');

commit;

  END IF; -- Schema version check
END
//
DELIMITER ;

CALL update_gh_schema();

DROP PROCEDURE update_gh_schema;